@@ -26,24 +26,21 @@ as_tidytable <- function(x, ...,
 }
 
 #' @export
-as_tidytable.tidytable <- function(x, ...,
-                                   .name_repair = "unique") {
+as_tidytable.tidytable <- function(x, ..., .name_repair = "unique") {
   x
 }
 
 #' @export
-as_tidytable.data.table <- function(x, ...,
-                                    .name_repair = "unique") {
-  x <- add_tidytable_class(x)
-
-  df_name_repair(x, .name_repair = .name_repair)
+as_tidytable.data.table <- function(x, ..., .name_repair = "unique") {
+  x <- set_class(x)
+  df_name_repair(x, .name_repair)
 }
 
 #' @export
 as_tidytable.data.frame <- function(x, ...,
                                     .name_repair = "unique",
                                     .keep_rownames = FALSE) {
-  out <- fast_copy(new_tidytable(x))
+  out <- new_tidytable(x)
 
   if (!is_false(.keep_rownames)) {
     if (is.character(.keep_rownames)) {
@@ -57,26 +54,30 @@ as_tidytable.data.frame <- function(x, ...,
     out <- vec_cbind(row_names, out)
   }
 
-  df_name_repair(out, .name_repair = .name_repair)
+  df_name_repair(out, .name_repair)
 }
 
 #' @export
-as_tidytable.list <- function(x, ...,
-                              .name_repair = "unique") {
+as_tidytable.list <- function(x, ..., .name_repair = "unique") {
   x <- df_list(!!!x, .name_repair = .name_repair)
   new_tidytable(x)
 }
 
+#' @export
+as_tidytable.grouped_tt <- function(x, ...) {
+  new_tidytable(x)
+}
+
+#' @export
+as_tidytable.rowwise_tt <- function(x, ...) {
+  new_tidytable(x)
+}
+
 #' @export
 as_tidytable.default <- function(x, ...,
                                  .name_repair = "unique",
                                  .keep_rownames = FALSE) {
   out <- as.data.table(x, .keep_rownames)
-  out <- add_tidytable_class(out)
-  df_name_repair(out, .name_repair = .name_repair)
-}
-
-add_tidytable_class <- function(x) {
-  class(x) <- c("tidytable", "data.table", "data.frame")
-  x
+  out <- set_class(out)
+  df_name_repair(out, .name_repair)
 }
