@@ -15,10 +15,10 @@
 #' df <- tidytable(x = 1:10)
 #'
 #' df %>%
-#'   mutate.(case_x = case.(x < 5, 1,
+#'   mutate(case_x = case(x < 5, 1,
 #'                          x < 7, 2,
 #'                          default = 3))
-case. <- function(..., default = NA) {
+case <- function(..., default = NA) {
   dots <- list2(...)
   dots_length <- length(dots)
 
@@ -50,3 +50,8 @@ case. <- function(..., default = NA) {
 
   out
 }
+
+#' @export
+#' @keywords internal
+#' @inherit case
+case. <- case
