@@ -1,7 +1,7 @@
 #' Create a data.table from all unique combinations of inputs
 #'
 #' @description
-#' `crossing.()` is similar to `expand_grid.()` but de-duplicates and sorts its inputs.
+#' `crossing()` is similar to `expand_grid()` but de-duplicates and sorts its inputs.
 #'
 #' @param ... Variables to get unique combinations of
 #' @param .name_repair Treatment of problematic names. See `?vctrs::vec_as_names` for options/details
@@ -12,14 +12,14 @@
 #' x <- 1:2
 #' y <- 1:2
 #'
-#' crossing.(x, y)
+#' crossing(x, y)
 #'
-#' crossing.(stuff = x, y)
-crossing. <- function(..., .name_repair = "check_unique") {
+#' crossing(stuff = x, y)
+crossing <- function(..., .name_repair = "check_unique") {
   dots <- dots_list(..., .named = TRUE)
-  dots <- map.(dots, sort_unique)
+  dots <- map(dots, sort_unique)
 
-  expand_grid.(!!!dots, .name_repair = .name_repair)
+  expand_grid(!!!dots, .name_repair = .name_repair)
 }
 
 sort_unique <- function(x) {
@@ -34,3 +34,8 @@ sort_unique <- function(x) {
     f_sort(vec_unique(x))
   }
 }
+
+#' @export
+#' @keywords internal
+#' @inherit crossing
+crossing. <- crossing
