@@ -16,13 +16,20 @@
 #' )
 #'
 #' df %>%
-#'   drop_na.()
+#'   drop_na()
 #'
 #' df %>%
-#'   drop_na.(x)
+#'   drop_na(x)
 #'
 #' df %>%
-#'   drop_na.(where(is.numeric))
+#'   drop_na(where(is.numeric))
+drop_na <- function(.df, ...) {
+  drop_na.(.df, ...)
+}
+
+#' @export
+#' @keywords internal
+#' @inherit drop_na
 drop_na. <- function(.df, ...) {
   UseMethod("drop_na.")
 }
@@ -43,5 +50,6 @@ drop_na..tidytable <- function(.df, ...) {
 #' @export
 drop_na..data.frame <- function(.df, ...) {
   .df <- as_tidytable(.df)
-  drop_na.(.df, ...)
+  drop_na(.df, ...)
 }
+
