@@ -67,7 +67,7 @@ dt.tidytable <- function(.df, ...) {
         .df <- fast_copy(.df, col_name)
       } else {
         # .df[, let(x = 1, double_y = y * 2)]
-        use_walrus <- map_lgl.(mut_exprs, is_call, ":=")
+        use_walrus <- map_lgl(mut_exprs, is_call, ":=")
         if (any(use_walrus)) {
           # .df %>% dt(, let(!!col := !!col * 2))
           j <- prep_j_expr(mut_exprs, use_walrus, ":=")
@@ -78,7 +78,7 @@ dt.tidytable <- function(.df, ...) {
       }
     } else if (is_call(j, c(".", "list"))) {
       summarize_exprs <- as.list(j[-1])
-      use_walrus <- map_lgl.(summarize_exprs, is_call, ":=")
+      use_walrus <- map_lgl(summarize_exprs, is_call, ":=")
       if (any(use_walrus)) {
         # .df %>% dt(, .(!!col := mean(!!col)))
         j <- prep_j_expr(summarize_exprs, use_walrus, ".")
@@ -97,11 +97,24 @@ dt.tidytable <- function(.df, ...) {
   eval_tidy(dt_expr, env = dt_env)
 }
 
+#' @export
+dt.grouped_tt <- function(.df, ...) {
+  warn("Output is ungrouped when using `dt()` on a grouped tidytable.")
+  .df <- ungroup(.df)
+  dt(.df, ...)
+}
+
+#' @export
+dt.data.frame <- function(.df, ...) {
+  .df <- as_tidytable(.df)
+  dt(.df, ...)
+}
+
 prep_j_expr <- function(j_exprs, use_walrus, j_call) {
   walrus_exprs <- j_exprs[use_walrus]
-  walrus_exprs <- map.(walrus_exprs, ~ as.list(.x[-1]))
-  walrus_names <- map_chr.(walrus_exprs, ~ as.character(.x[[1]]))
-  walrus_exprs <- map.(walrus_exprs, ~ .x[[2]])
+  walrus_exprs <- map(walrus_exprs, ~ as.list(.x[-1]))
+  walrus_names <- map_chr(walrus_exprs, ~ as.character(.x[[1]]))
+  walrus_exprs <- map(walrus_exprs, ~ .x[[2]])
   j_exprs[use_walrus] <- walrus_exprs
   names(j_exprs)[use_walrus] <- walrus_names
 
@@ -117,9 +130,3 @@ replace_j_dot <- function(dots, dots_names, j) {
   }
   dots
 }
-
-#' @export
-dt.data.frame <- function(.df, ...) {
-  .df <- as_tidytable(.df)
-  dt(.df, ...)
-}
