@@ -17,10 +17,17 @@
 #' )
 #'
 #' df %>%
-#'   filter.(a >= 2, b >= 4)
+#'   filter(a >= 2, b >= 4)
 #'
 #' df %>%
-#'   filter.(b <= mean(b), .by = c)
+#'   filter(b <= mean(b), .by = c)
+filter <- function(.df, ..., .by = NULL) {
+  filter.(.df, ..., .by = {{ .by }})
+}
+
+#' @export
+#' @keywords internal
+#' @inherit filter
 filter. <- function(.df, ..., .by = NULL) {
   UseMethod("filter.")
 }
@@ -47,24 +54,33 @@ filter..tidytable <- function(.df, ..., .by = NULL) {
   eval_tidy(dt_expr, .df, dt_env)
 }
 
+#' @export
+filter..grouped_tt <- function(.df, ..., .by = NULL) {
+  check_by({{ .by }})
+  .by <- group_vars(.df)
+  out <- ungroup(.df)
+  out <- filter(out, ..., .by = all_of(.by))
+  group_by(out, all_of(.by))
+}
+
 #' @export
 filter..data.frame <- function(.df, ..., .by = NULL) {
   .df <- as_tidytable(.df)
-  filter.(.df, ..., .by = {{ .by }})
+  filter(.df, ..., .by = {{ .by }})
 }
 
 check_filter <- function(dots) {
-  named_bool <- have_name(dots)
+  .is_named <- have_name(dots)
 
-  if (any(named_bool)) {
-    named_dots <- dots[named_bool]
+  if (any(.is_named)) {
+    named_dots <- dots[.is_named]
 
-    i <- which(named_bool)[[1]]
+    i <- which(.is_named)[[1]]
     dot <- as_label(quo_get_expr(named_dots[[1]]))
     dot_name <- names(named_dots[1])
 
     abort(c(
-      glue("Problem with `filter.()` input `..{i}`."),
+      glue("Problem with `filter()` input `..{i}`."),
       x = glue("Input `..{i}` is named."),
       i = glue("This usually means that you've used `=` instead of `==`."),
       i = glue("Did you mean `{dot_name} == {dot}`?")
