@@ -14,14 +14,17 @@
 #' df <- tidytable(x = 1:4, y = 1:4)
 #'
 #' df %>%
-#'   filter.(x %in% c(2, 4))
+#'   filter(x %in% c(2, 4))
 #'
 #' df %>%
-#'   filter.(x %notin% c(2, 4))
+#'   filter(x %notin% c(2, 4))
 #' @rdname in-notin
 '%in%' <- function(x, y) {
   if (is.character(x) && is.character(y)) {
     x %chin% y
+  } else if (is.list(y)) {
+    # https://github.com/markfairbanks/tidytable/issues/565
+    base::'%in%'(x, y)
   } else {
     vec_in(x, y)
   }
