@@ -1,7 +1,7 @@
-# "Prepare" quosures/expressions for use in a "[.data.table" call
-# Allows the use of functions like n() and across.()
-# Replaces these functions with the necessary data.table translations
-# Adapted from dt_squash found here: https://github.com/tidyverse/dtplyr/blob/master/R/tidyeval.R
+# "Prepare" quosures/expressions for use in a `[.data.table` call
+#   Allows the use of functions like n() and across()
+#   Replaces these functions with the necessary data.table translations
+#   Adapted from dt_squash found here: https://github.com/tidyverse/dtplyr/blob/master/R/tidyeval.R
 prep_exprs <- function(x, data, .by = NULL, j = FALSE, dt_env = caller_env(), is_top_across = TRUE) {
   x <- lapply(x, prep_expr, data, {{ .by }}, j = j, dt_env = dt_env, is_top_across)
   squash(x)
@@ -26,26 +26,28 @@ prep_expr <- function(x, data, .by = NULL, j = FALSE, dt_env = caller_env(), is_
 }
 
 tidytable_fns <- c(
-  "arrange.",
-  "filter.",
-  "mutate.",
-  "slice.",
-  "summarise.", "summarize."
+  "arrange.", "arrange",
+  "filter.", "filter",
+  "mutate.", "mutate",
+  "slice.", "slice",
+  "summarise.", "summarise.", "summarize.", "summarize"
 )
 
 call_fns <- c(
   "$", "[[",
-  "across.", "between",
-  "c_across.", "case_when",
+  "across.", "across",
+  "c_across.", "c_across",
   "cur_data.", "cur_data",
-  "cur_group_rows.", "cur_group_rows", "cur_group_id.", "cur_group_id",
+  "cur_group_rows.", "cur_group_rows",
+  "cur_group_id.", "cur_group_id",
   "desc.", "desc",
   "function",
   "glue",
-  "ifelse", "if_else",
-  "if_all.", "if_any.",
-  "n.", "n", "row_number.", "row_number",
-  "replace_na",
+  "if_all.",  "if_all",
+  "if_any.", "if_any",
+  "ifelse",
+  "n.", "n",
+  "row_number.", "row_number",
   "str_glue"
 )
 
@@ -62,38 +64,27 @@ prep_expr_call <- function(x, data, .by = NULL, j = FALSE, dt_env = caller_env()
     quote(.GRP)
   } else if (is_call(x, c("cur_data.", "cur_data"))) {
     quote(.SD)
-  } else if (is_call(x, c("ifelse", "if_else"))) {
-    if (is_call(x, "if_else")) {
-      x <- call_match(x, tidytable::if_else.)
-    } else {
-      x <- call_match(x, base::ifelse)
-    }
+  } else if (is_call(x, "ifelse", ns = "")) {
+    x <- call_match(x, base::ifelse)
     x <- unname(x)
-    x[[1]] <- quote(tidytable::if_else.)
+    x[[1]] <- quote(tidytable::if_else)
     x[-1] <- lapply(x[-1], prep_expr, data, {{ .by }}, j, dt_env, is_top_across)
     x
-  } else if (is_call(x, "case_when", ns = "")) {
-    x[[1]] <- quote(tidytable::case_when.)
-    x[-1] <- lapply(x[-1], prep_expr, data, {{ .by }}, j, dt_env, is_top_across)
-    x
-  } else if (is_call(x, "replace_na")) {
-    x[[1]] <- quote(tidytable::replace_na.)
-    x
-  } else if (is_call(x, "c_across.")) {
+  } else if (is_call(x, c("c_across.", "c_across"))) {
     call <- call_match(x, tidytable::c_across.)
     cols <- get_across_cols(data, call$cols, {{ .by }}, dt_env)
     cols <- syms(cols)
     call2("vec_c", !!!cols, .ns = "vctrs")
-  } else if (is_call(x, c("if_all.", "if_any."))) {
-    call <- call_match(x, tidytable::if_all.)
+  } else if (is_call(x, c("if_all.", "if_all", "if_any.", "if_any"))) {
+    call <- call_match(x, tidytable::if_all)
     if (is.null(call$.fns)) return(TRUE)
     .cols <- get_across_cols(data, call$.cols, {{ .by }}, dt_env)
-    call_list <- map.(.cols, ~ fn_to_expr(call$.fns, .x))
-    reduce_fn <- if (is_call(x, "if_all.")) "&" else "|"
+    call_list <- map(.cols, ~ fn_to_expr(call$.fns, .x))
+    reduce_fn <- if (is_call(x, c("if_all.", "if_all"))) "&" else "|"
     filter_expr <- call_reduce(call_list, reduce_fn)
     prep_expr(filter_expr, data, {{ .by }})
-  } else if (is_call(x, "across.")) {
-    call <- call_match(x, tidytable::across., dots_expand = FALSE)
+  } else if (is_call(x, c("across.", "across"))) {
+    call <- call_match(x, tidytable::across, dots_expand = FALSE)
     .cols <- get_across_cols(data, call$.cols, {{ .by }}, dt_env)
     dots <- call$...
     call_list <- expand_across(call$.fns, .cols, call$.names, dots)
@@ -112,9 +103,6 @@ prep_expr_call <- function(x, data, .by = NULL, j = FALSE, dt_env = caller_env()
       glue_call$.envir <- quote(.SD)
     }
     glue_call
-  } else if (is_call(x, "between", ns = "")) {
-    x[[1]] <- quote(tidytable::between.)
-    x
   } else if (is_data_pronoun(x)) {
     var <- x[[3]]
     if (is_call(x, "[[")) {
