@@ -1,7 +1,7 @@
 test_that("can arrange the dataset", {
   df <- data.table(x = c(4, 3, 9, 7), y = 1:4)
   df <- df %>%
-    arrange.(x)
+    arrange(x)
 
   expect_equal(df$x, c(3, 4, 7, 9))
 })
@@ -9,7 +9,7 @@ test_that("can arrange the dataset", {
 test_that("can convert and arrange a data.frame", {
   df <- data.frame(x = c(4, 3, 9, 7), y = 1:4)
   df <- df %>%
-    arrange.(x)
+    arrange(x)
 
   expect_equal(df$x, c(3, 4, 7, 9))
 })
@@ -17,31 +17,31 @@ test_that("can convert and arrange a data.frame", {
 test_that("can arrange the dataset descending", {
   df <- data.table(x = c(4, 3, 9, 7), y = 1:4)
   df <- df %>%
-    arrange.(-x)
+    arrange(-x)
 
   expect_equal(df$x, c(9, 7, 4, 3))
 })
 
-test_that("can arrange the dataset with desc.()", {
+test_that("can arrange the dataset with desc()", {
   df <- data.table(x = c(4, 3, 9, 7), y = 1:4)
 
   desc_df <- df %>%
-    arrange.(desc.(x))
+    arrange(desc(x))
 
   check_df <- df %>%
-    arrange.(-x)
+    arrange(-x)
 
   expect_equal(desc_df, check_df)
 })
 
-test_that("can arrange the dataset with desc.() on chr", {
+test_that("can arrange the dataset with desc() on chr", {
   df <- data.table(x = c("a", "a", "b"), y = 1:3)
 
   desc_df <- df %>%
-    arrange.(desc.(x))
+    arrange(desc(x))
 
   check_df <- df %>%
-    arrange.(-x)
+    arrange(-x)
 
   expect_equal(desc_df, check_df)
 })
@@ -53,10 +53,10 @@ test_that("desc works with internal quosure", {
   desc_expr <- expr(desc(!!desc_col))
 
   desc_df <- df %>%
-    arrange.(!!desc_expr)
+    arrange(!!desc_expr)
 
   check_df <- df %>%
-    arrange.(-x)
+    arrange(-x)
 
   expect_equal(desc_df, check_df)
 })
@@ -65,10 +65,10 @@ test_that("desc wworks with .data pronoun", {
   df <- data.table(x = c(4, 3, 9, 7), y = 1:4)
 
   desc_df <- df %>%
-    arrange.(desc(.data$x))
+    arrange(desc(.data$x))
 
   check_df <- df %>%
-    arrange.(-x)
+    arrange(-x)
 
   expect_equal(desc_df, check_df)
 })
@@ -76,7 +76,7 @@ test_that("desc wworks with .data pronoun", {
 test_that("can arrange with multiple conditions", {
   df <- data.table(x = c(4, 3, 2, 1), y = c("a", "a", "b", "b"))
   df <- df %>%
-    arrange.(y, x)
+    arrange(y, x)
 
   expect_equal(df$x, c(3, 4, 1, 2))
 })
@@ -86,7 +86,7 @@ test_that("can make function with quosures", {
 
   arrange_fn <- function(.df, col) {
     .df %>%
-      arrange.({{col}})
+      arrange({{col}})
   }
 
   df <- df %>%
@@ -99,7 +99,7 @@ test_that("can make function with quosures", {
 test_that("can use .data", {
   df <- data.table(x = c(4, 3, 9, 7), y = 1:4)
   df <- df %>%
-    arrange.(.data$x)
+    arrange(.data$x)
 
   expect_equal(df$x, c(3, 4, 7, 9))
 })
@@ -107,7 +107,7 @@ test_that("can use .data", {
 test_that("can use a transmute expression", {
   df <- data.table(x = 1:3, y = 1:3, z = 3:1)
   res <- df %>%
-    arrange.(x - y, z)
+    arrange(x - y, z)
 
   expect_equal(res$x, 3:1)
 })
@@ -116,7 +116,7 @@ test_that("can use `.env`", {
   df <- data.table(x = c(4, 3, 9, 7))
   y <- 1
   res <- df %>%
-    arrange.(x + .env$y)
+    arrange(x + .env$y)
 
   expect_equal(res$x, c(3, 4, 7, 9))
 })
@@ -124,7 +124,15 @@ test_that("can use `.env`", {
 test_that("properly orders NAs, #541", {
   df <- data.table(x = c(NA, "b", "a"))
   res <- df %>%
-    arrange.(x)
+    arrange(x)
 
   expect_equal(res$x, c("a", "b", NA))
 })
+
+test_that("works with dot", {
+  df <- data.table(x = c(4, 3, 9, 7), y = 1:4)
+  df <- df %>%
+    arrange.(x)
+
+  expect_equal(df$x, c(3, 4, 7, 9))
+})
