@@ -1,7 +1,7 @@
 test_that("works on all rows", {
   test_df <- tidytable(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.()
+    distinct()
 
   expect_equal(names(test_df), names(distinct_df))
   expect_equal(distinct_df$c, c("a", "b"))
@@ -10,7 +10,7 @@ test_that("works on all rows", {
 test_that("works on a data.frame", {
   test_df <- data.frame(a = 1:3, b = 4:6, c = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.()
+    distinct()
 
   expect_equal(names(test_df), names(distinct_df))
   expect_equal(as_tidytable(test_df), distinct_df)
@@ -19,7 +19,7 @@ test_that("works on a data.frame", {
 test_that("works on 1 column", {
   test_df <- data.table(a = 1:3, b = c(4,4,5), c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.(b)
+    distinct(b)
 
   expect_named(distinct_df, c("b"))
   expect_equal(distinct_df$b, c(4, 5))
@@ -28,7 +28,7 @@ test_that("works on 1 column", {
 test_that("works on 1 column and can utilize renaming", {
   test_df <- data.table(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.(stuff = b)
+    distinct(stuff = b)
 
   expect_named(distinct_df, c("stuff"))
   expect_equal(distinct_df$stuff, c(2))
@@ -37,7 +37,7 @@ test_that("works on 1 column and can utilize renaming", {
 test_that("works on 1 column and can utilize renaming with .keep_all = TRUE", {
   test_df <- data.table(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.(stuff = b, .keep_all = TRUE)
+    distinct(stuff = b, .keep_all = TRUE)
 
   expect_named(distinct_df, c("a", "stuff", "c", "d"))
   expect_equal(distinct_df$stuff, c(2))
@@ -46,7 +46,7 @@ test_that("works on 1 column and can utilize renaming with .keep_all = TRUE", {
 test_that("works with enhanced selection", {
   test_df <- data.table(a = 1:3, b = 4:6, c = c("a", "a", "b"), d = c("a", "a", "b"))
   distinct_df <- test_df %>%
-    distinct.(where(is.character))
+    distinct(where(is.character))
 
   expect_named(distinct_df, c("c", "d"))
   expect_equal(distinct_df$c, c("a", "b"))
@@ -58,7 +58,7 @@ test_that("can make a function with quosures", {
 
   distinct_fn <- function(.df, col) {
     .df %>%
-      distinct.({{col}})
+      distinct({{col}})
   }
   distinct_df <- test_df %>%
     distinct_fn(b)
@@ -74,7 +74,7 @@ test_that("can find environment vars in custom functions, #392", {
     var_names <- char_varlist
 
     data %>%
-      distinct.(all_of(var_names))
+      distinct(all_of(var_names))
   }
 
   result_df <- df %>%
@@ -84,4 +84,11 @@ test_that("can find environment vars in custom functions, #392", {
   expect_equal(result_df$y, c("a", "b"))
 })
 
+test_that("distinct. works", {
+  test_df <- tidytable(a = rep(1, 3), b = rep(2, 3), c = c("a", "a", "b"))
+  distinct_df <- test_df %>%
+    distinct.()
 
+  expect_equal(names(test_df), names(distinct_df))
+  expect_equal(distinct_df$c, c("a", "b"))
+})
