@@ -1,4 +1,12 @@
 test_that("default removes old column and returns first alpha group", {
+  data.table(y = c("a1-1", "b2-2", "c3-3")) -> test_df
+  test_df %>% extract(y, "A", regex="([[:alnum:]]+)") -> results_df
+
+  expect_equal(results_df$A, c("a1", "b2", "c3"))
+  expect_null(results_df$y)
+})
+
+test_that("extract. works", {
   data.table(y = c("a1-1", "b2-2", "c3-3")) -> test_df
   test_df %>% extract.(y, "A", regex="([[:alnum:]]+)") -> results_df
 
@@ -8,21 +16,21 @@ test_that("default removes old column and returns first alpha group", {
 
 test_that("doesn't modify-by-reference", {
   data.table(y = c("a1-1", "b2-2", "c3-3")) -> test_df
-  test_df %>% extract.(y, "A", regex="([[:alnum:]]+)")
+  test_df %>% extract(y, "A", regex="([[:alnum:]]+)")
 
   expect_equal(test_df$y, c("a1-1", "b2-2", "c3-3"))
 })
 
 test_that("match failures give NAs", {
   data.table(y = c("a1-1", "b2-2", "c3-3")) -> test_df
-  test_df %>% extract.(y, "A", regex="(b)") -> results_df
+  test_df %>% extract(y, "A", regex="(b)") -> results_df
   expect_equal(results_df$A, c(NA, "b", NA))
 })
 
 
 test_that("can match multiple groups", {
   data.table(y = c("a1-1", "b2-2", "c3-3")) -> test_df
-  test_df %>% extract.(y, c("A", "B"), regex="([[:alnum:]]+)-([[:alnum:]]+)") -> results_df
+  test_df %>% extract(y, c("A", "B"), regex="([[:alnum:]]+)-([[:alnum:]]+)") -> results_df
 
   expect_equal(results_df$A, c("a1", "b2", "c3"))
   expect_equal(results_df$B, c("1", "2", "3"))
@@ -30,7 +38,7 @@ test_that("can match multiple groups", {
 
 test_that("can drop groups", {
   data.table(y = c("a1-1", "b2-2", "c3-3")) -> test_df
-  test_df %>% extract.(y, c("A", NA, "B"), regex="([[:alnum:]]+)(-)([[:alnum:]]+)") -> results_df
+  test_df %>% extract(y, c("A", NA, "B"), regex="([[:alnum:]]+)(-)([[:alnum:]]+)") -> results_df
 
   expect_named(results_df, c("A", "B"))
   expect_equal(results_df$B, c("1", "2", "3"))
@@ -38,7 +46,7 @@ test_that("can drop groups", {
 
 test_that("can combine groups into multiple columns", {
   data.table(y = "a1-1") -> test_df
-  test_df %>% extract.(y, c("A", "B", "B"), regex="([a-z])(\\d)-([[:alnum:]]+)") -> results_df
+  test_df %>% extract(y, c("A", "B", "B"), regex="([a-z])(\\d)-([[:alnum:]]+)") -> results_df
 
   expect_equal(results_df,  tidytable(A = "a", B = "11"))
 })
@@ -46,14 +54,14 @@ test_that("can combine groups into multiple columns", {
 test_that("errors when the extracted groups number is different then the provided `into` columns", {
   data.table(y = c("a1-1", "b2-2", "c3-3")) -> test_df
 
-  expect_error(test_df %>% extract.(y, c("A", "B"), regex = "a"), "should define 2 groups")
-  expect_error(test_df %>% extract.(y, 1:3, regex = "."), "should define 3 groups")
+  expect_error(test_df %>% extract(y, c("A", "B"), regex = "a"), "should define 2 groups")
+  expect_error(test_df %>% extract(y, 1:3, regex = "."), "should define 3 groups")
 })
 
 
 test_that("extract keeps characters as character", {
   test_df <- data.table(x = "X-1-T")
-  results_df <- extract.(test_df, x, c("A", "B", "C"), "(.)-(.)-(.)", convert = TRUE)
+  results_df <- extract(test_df, x, c("A", "B", "C"), "(.)-(.)-(.)", convert = TRUE)
   expect_equal(results_df$A, "X")
   expect_equal(results_df$B, 1L)
   expect_equal(results_df$C, TRUE)
